@@ -1,7 +1,7 @@
 package Perinci::Examples::ResultNaked;
 
-our $DATE = '2016-10-26'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $DATE = '2016-10-29'; # DATE
+our $VERSION = '0.76'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.75 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-10-26.
+This document describes version 0.76 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2016-10-29.
 
 =head1 DESCRIPTION
 
@@ -104,11 +104,11 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_naked(arg1 => "abc", arg2 => 10); # -> ["arg1", "abc", "arg2", 10]
+ result_naked(arg1 => "abc", arg2 => 10); # -> ["arg2", 10, "arg1", "abc"]
 
 =item * With the optional arg3:
 
- result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg2", 20, "arg1", "def", "arg3", 0.5]
+ result_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg1", "def", "arg2", 20, "arg3", 0.5]
 
 =back
 
@@ -147,7 +147,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg1", "def", "arg2", 20, "arg3", 0.5], {}]
+ [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
 
 =back
 
@@ -182,7 +182,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
 
 =head1 BUGS
 
